@@ -122,7 +122,18 @@ namespace Configuration {							/*{{{*/
 	APT_PUBLIC std::vector<std::string> const getBuildProfiles();
 	/** \return Return a comma-separated list of enabled build profile specifications */
 	APT_PUBLIC std::string const getBuildProfilesString();
-									/*}}}*/
+
+	std::string const getMachineID();
+
+#ifdef APT_COMPILING_APT
+	/** \return Whether we are running in a chroot */
+	APT_PUBLIC bool isChroot();
+	/** \return Check usr is merged or produce error. */
+	APT_PUBLIC bool checkUsrMerged();
+	APT_PUBLIC std::string color(std::string const &colorName, std::string const &content = "");
+#endif
+
+	/*}}}*/
 }
 									/*}}}*/
 }
